@@ -9,7 +9,8 @@ require Exporter;
     format_seq
 
     validate_sequence 
-    revcom 
+    complement
+    revcom
     base_content 
     degenerate_seq_to_regexp
     degenerate_seq_match_sites
@@ -42,11 +43,11 @@ hoping it would be helpful.
 
 =head1 VERSION
 
-Version 2014.1116
+Version 2014.1202
 
 =cut
 
-our $VERSION = 2014.1116;
+our $VERSION = 2014.1202;
 
 =head1 EXPORT
 
@@ -56,6 +57,7 @@ our $VERSION = 2014.1116;
     format_seq
 
     validate_sequence 
+    complement
     revcom 
     base_content 
     degenerate_seq_to_regexp
@@ -80,18 +82,24 @@ our $VERSION = 2014.1116;
 
 FastaReader is a fasta file parser using closure.
 FastaReader returns an anonymous subroutine, when called, it
-will return a fasta record which is reference of an array
+return a fasta record which is reference of an array
 containing fasta header and sequence.
 
+FastaReader could also read from STDIN when the file name is "STDIN".
+
 A boolean argument is optional. If set as "true", "return" ("\r") and
 "new line" ("\n") symbols in sequence will not be trimed.
 
 Example:
 
+   # do not trim the spaces and \n
    # $not_trim = 1;
    # my $next_seq = FastaReader("test.fa", $not_trim);
    
+   # read from STDIN
    # my $next_seq = FastaReader('STDIN');
+   
+   # read from file
    my $next_seq = FastaReader("test.fa");
 
    while ( my $fa = &$next_seq() ) {
@@ -112,7 +120,7 @@ sub FastaReader {
     my $fh       = undef;
     my $is_stdin = 0;
 
-    if ( $file eq 'STDIN' ) {
+    if ( $file =~ /^STDIN$/i ) {
         $fh       = *STDIN;
         $is_stdin = 1;
     }
@@ -260,6 +268,20 @@ sub validate_sequence {
     return 1;
 }
 
+=head2 complement
+
+Complement sequence
+
+my $comp = complement($seq);
+
+=cut
+
+sub complement {
+    $_[0] =~ tr/ACGTURYMKSWBDHVNacgturymkswbdhvn/TGCAAYRKMWSVHDBNtgcaayrkmwsvhdbn/;
+    return $_[0];
+}
+
+
 =head2 revcom
 
 Reverse complement sequence
@@ -269,9 +291,7 @@ my $recom = revcom($seq);
 =cut
 
 sub revcom {
-    my ($s) = @_;
-    $s =~ tr/ACGTRYMKSWBDHVNacgtrymkswbdhvn/TGCAYRKMWSVHDBNtgcayrkmwsvhdbn/;
-    return reverse $s;
+    return reverse complement($_[0]);
 }
 
 =head2 base_content
